@@ -15,30 +15,39 @@ def join_by_key(key):
     return formatter
 
 
-def reformat_quotas(quotas):
+def reformat_limits(quotas):
     result = []
     for resource, quota in quotas.items():
-        quota = sort_list_of_dicts(quota, "region")
+        if quota[0].get("zone"):
+            quota = sort_list_of_dicts(quota, "zone")
         result.append({
             "resource": resource,
-            "region": [q["region"] for q in quota],
-            "zone": [q["zone"] or str() for q in quota],
-            "value": [str(q["value"]) for q in quota]
+            "value": [str(q["value"]) for q in quota],
+            "zone": [q["zone"] if q.get("zone") else str() for q in quota]
         })
     return result
 
 
-def reformat_quotas_with_usages(val):
+def reformat_quotas(quotas):
     result = []
-    for project, quotas in val.items():
-        for resource, quota in quotas.items():
-            quota = sort_list_of_dicts(quota, "zone")
-            result.append({
-                "project_id": project,
-                "resource": resource,
-                "region": [q["region"] for q in quota],
-                "zone": [q["zone"] or str() for q in quota],
-                "value": [str(q["value"]) for q in quota],
-                "used": [str(q["used"]) for q in quota],
-            })
+    for resource, quota in quotas.items():
+        quota = sort_list_of_dicts(quota, "zone")
+        result.append({
+            "resource": resource,
+            "zone": [q["zone"] or str() for q in quota],
+            "value": [str(q["value"]) for q in quota],
+        })
+    return result
+
+
+def reformat_quotas_with_usages(quotas):
+    result = []
+    for resource, quota in quotas.items():
+        quota = sort_list_of_dicts(quota, "zone")
+        result.append({
+            "resource": resource,
+            "zone": [q["zone"] or str() for q in quota],
+            "value": [str(q["value"]) for q in quota],
+            "used": [str(q["used"]) for q in quota],
+        })
     return result
